/**
 * Copyright (C) 2006  Bull S. A. S.
 * Bull, Rue Jean Jaures, B.P.68, 78340, Les Clayes-sous-Bois
 * This library is free software; you can redistribute it and/or modify it under the terms
 * of the GNU Lesser General Public License as published by the Free Software Foundation
 * version 2.1 of the License.
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 * You should have received a copy of the GNU Lesser General Public License along with this
 * program; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
 * Floor, Boston, MA  02110-1301, USA.
 **/
package org.ow2.bonita.facade.def.majorElement;

import java.io.Serializable;
import java.util.Collection;
import java.util.Date;
import java.util.Map;
import java.util.Set;

import org.ow2.bonita.facade.def.element.BusinessArchive;
import org.ow2.bonita.facade.uuid.ProcessDefinitionUUID;

/**
 * This interface represents the Process definition.
 * It's derived from the WorkflowProcess of XPDL.
 */
public interface ProcessDefinition extends Serializable, NamedElement {
 
  /**
   * Version of this process definition.
   */
  String getVersion();

  Set<DataFieldDefinition> getDataFields();
  Set<ParticipantDefinition> getParticipants();
  Set<ActivityDefinition> getActivities();
  Set<TransitionDefinition> getTransitions();
  
  Map<String, String> getMetaData();
  String getAMetaData(String key);
  
  /**
   * Workflow process state.<br>
   */
  public static enum ProcessState {
    DEPLOYED, UNDEPLOYED
  }

  /**
   * Returns the UUID for the ProcessDefinition.
   */
  ProcessDefinitionUUID getUUID();

  ProcessState getState();
  
  /**
   * If the package has subflows and the process definition for these subflows
   * are defined in others package definitions then it is not possible to undeploy
   * these packages until this package is itself undeployed.
   * @return The (unordered) set of package processDefinitionUUID depending on this package definition.
   */
  Set<String> getProcessDependencies();
  /**
   * Returns class dependencies (java classDatas for hooks, mappers, performer assignments, deadlines)
   * for this package.
   * @return The (unordered) set of classDatas on which this package depends on.
   */
  Set<String> getClassDependencies();

  BusinessArchive getBusinessArchive();
  
  /**
   * Returns the date when the package is deployed.
   */
  Date getDeployedDate();
  /**
   * Returns the date where the package is undeployed.
   */
  Date getUndeployedDate();
  /**
   * Returns the user deploying the package.
   */
  String getDeployedBy();
  /**
   * Returns the user undeploying the package.
   */
  String getUndeployedBy();
  
  /**
   * Return all activities of this process having no incoming transitions.
   * @return
   */
  Collection<ActivityDefinition> getFirstActivities();
  
  /**
   * Returns the acitivty with the given name. Null if no activity exists within the process with the given name.
   * @param name
   * @return
   */
  ActivityDefinition getActivity(final String name);
  
}
