/**
 * Copyright (C) 2006  Bull S. A. S.
 * Bull, Rue Jean Jaures, B.P.68, 78340, Les Clayes-sous-Bois
 * This library is free software; you can redistribute it and/or modify it under the terms
 * of the GNU Lesser General Public License as published by the Free Software Foundation
 * version 2.1 of the License.
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 * You should have received a copy of the GNU Lesser General Public License along with this
 * program; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
 * Floor, Boston, MA  02110-1301, USA.
 * 
 * Modified by Matthieu Chaffotte - BonitaSoft S.A.
 **/
package org.ow2.bonita.facade.def.majorElement.impl;

import java.io.Serializable;
import java.util.Collections;
import java.util.Set;

import org.ow2.bonita.facade.def.majorElement.DataFieldDefinition;
import org.ow2.bonita.facade.uuid.ActivityDefinitionUUID;
import org.ow2.bonita.facade.uuid.DataFieldDefinitionUUID;
import org.ow2.bonita.facade.uuid.ProcessDefinitionUUID;
import org.ow2.bonita.util.BonitaRuntimeException;
import org.ow2.bonita.util.CopyTool;
import org.ow2.bonita.util.Misc;

public class DataFieldDefinitionImpl extends ProcessElementImpl implements DataFieldDefinition {

  private static final long serialVersionUID = 3520847216843051032L;
  protected DataFieldDefinitionUUID uuid;
  protected String dataTypeClassName;
  protected Set<String> enumerationValues;
  protected byte[] initialValue;

  protected DataFieldDefinitionImpl() { }

  public DataFieldDefinitionImpl(final ProcessDefinitionUUID processUUID, final String name, final String dataTypeClassName) {
    super(name, processUUID);
    this.uuid = new DataFieldDefinitionUUID(processUUID, name);
    this.dataTypeClassName = dataTypeClassName;
  }
  
  public DataFieldDefinitionImpl(final ActivityDefinitionUUID activityUUID, final String name, final String dataTypeClassName) {
    super(name, activityUUID.getProcessUUID());
    this.uuid = new DataFieldDefinitionUUID(activityUUID, name);
    this.dataTypeClassName = dataTypeClassName;
  }

  public DataFieldDefinitionImpl(DataFieldDefinition src) {
    super(src);
    this.uuid = new DataFieldDefinitionUUID(src.getUUID());
    this.dataTypeClassName = src.getDataTypeClassName();
    
    DataFieldDefinitionImpl srcImpl = (DataFieldDefinitionImpl) src;
    this.initialValue = srcImpl.initialValue;
    this.enumerationValues = CopyTool.copy(src.getEnumerationValues());

  }

  public String getDataTypeClassName() {
    return dataTypeClassName;
  }

  public Serializable getInitialValue() {
    if (initialValue != null) {
      try {
        return (Serializable) Misc.deserialize(initialValue);
      } catch (Exception e) {
        throw new BonitaRuntimeException("Unable to serialize initialValue");
      }
    }
    return null;
  }

  public DataFieldDefinitionUUID getUUID() {
    return uuid;
  }

  public Set<String> getEnumerationValues() {
    if (this.enumerationValues != null) {
      return this.enumerationValues;
    }
    return Collections.emptySet();
  }

  public void setEnumerationValues(Set<String> enumerationValues) {
    this.enumerationValues = enumerationValues;
  }

  public void setInitialValue(Serializable initialValue) {
    if (initialValue != null) {
      try {
        this.initialValue = Misc.serialize(initialValue);
      } catch (Exception e) {
        throw new BonitaRuntimeException("Unable to serialize initialValue");
      }
    }
  }

  public boolean isEnumeration() {
    return dataTypeClassName.equals(String.class.getName()) && enumerationValues != null && enumerationValues.size() > 0;
  }
  
  @Override
  public boolean equals(Object o) {
    if (o == null) {
      return false;
    }
    if (!o.getClass().equals(this.getClass())) {
      return false;
    }
    DataFieldDefinitionImpl other = (DataFieldDefinitionImpl) o;
    return other.getUUID().equals(this.getUUID());
  }
}
