package org.ow2.bonita.facade.ejb.ejb2;

import java.lang.reflect.Proxy;
import java.rmi.RemoteException;
import java.util.Hashtable;

import javax.ejb.CreateException;
import javax.naming.NamingException;
import javax.rmi.PortableRemoteObject;

import org.ow2.bonita.facade.APIAccessor;
import org.ow2.bonita.facade.CommandAPI;
import org.ow2.bonita.facade.ManagementAPI;
import org.ow2.bonita.facade.RuntimeAPI;
import org.ow2.bonita.facade.ejb.ejb2.home.EJB2CommandAPIHome;
import org.ow2.bonita.facade.ejb.ejb2.home.EJB2ManagementAPIHome;
import org.ow2.bonita.facade.ejb.ejb2.home.EJB2RuntimeAPIHome;
import org.ow2.bonita.facade.exception.BonitaInternalException;
import org.ow2.bonita.facade.interceptor.ClientAPIInterceptor;
import org.ow2.bonita.facade.interceptor.EJBCommandAPIInterceptor;
import org.ow2.bonita.facade.internal.InternalCommandAPI;
import org.ow2.bonita.facade.internal.InternalManagementAPI;
import org.ow2.bonita.facade.internal.InternalRuntimeAPI;
import org.ow2.bonita.util.AccessorUtil;
import org.ow2.bonita.util.Misc;

public class EJB2APIAccessorImpl extends EJB2QueryAPIAccessorImpl implements APIAccessor {

  private InternalCommandAPI commandAPI;
  private InternalManagementAPI managementAPI;
  private InternalRuntimeAPI runtimeAPI;
  
  public EJB2APIAccessorImpl(Hashtable<String, String> jndiEnvironment) {
    super(jndiEnvironment);
  }
  
  public CommandAPI getCommandAPI() {
    if (commandAPI == null) {
      try {
        EJB2CommandAPIHome commandAPIHome = (EJB2CommandAPIHome) PortableRemoteObject.narrow(
            Misc.<Object>lookup(AccessorUtil.COMMANDAPI_JNDINAME, jndiEnvironment), EJB2CommandAPIHome.class);
        commandAPI = commandAPIHome.create();
      } catch (RemoteException e) {
        throw new BonitaInternalException(e.getMessage(), e);
      } catch (CreateException e) {
        throw new BonitaInternalException(e.getMessage(), e);
      } catch (NamingException e) {
        throw new BonitaInternalException(e.getMessage(), e);
      }
    }
    Class<CommandAPI> clazz = CommandAPI.class;
    ClientAPIInterceptor apiInterceptor = new ClientAPIInterceptor(commandAPI);
    CommandAPI ejbCommandAPI = (CommandAPI) Proxy.newProxyInstance(APIAccessor.class.getClassLoader(),
        new Class[] {clazz}, apiInterceptor);
    return new EJBCommandAPIInterceptor(ejbCommandAPI);
  }

  public ManagementAPI getManagementAPI() {
    if (managementAPI == null) {
      try {
        EJB2ManagementAPIHome managementAPIHome = (EJB2ManagementAPIHome) PortableRemoteObject.narrow(
            Misc.<Object>lookup(AccessorUtil.MANAGEMENT_JNDINAME, jndiEnvironment), EJB2ManagementAPIHome.class);
        managementAPI = managementAPIHome.create();
      } catch (RemoteException e) {
        throw new BonitaInternalException(e.getMessage(), e);
      } catch (CreateException e) {
        throw new BonitaInternalException(e.getMessage(), e);
      } catch (NamingException e) {
        throw new BonitaInternalException(e.getMessage(), e);
      }
    }
    Class<ManagementAPI> clazz = ManagementAPI.class;
    ClientAPIInterceptor apiInterceptor = new ClientAPIInterceptor(managementAPI);
    return (ManagementAPI) Proxy.newProxyInstance(APIAccessor.class.getClassLoader(),
        new Class[] {clazz}, apiInterceptor);
  }

  public RuntimeAPI getRuntimeAPI() {
    if (runtimeAPI == null) {
      try {
        EJB2RuntimeAPIHome runtimeAPIHome = (EJB2RuntimeAPIHome) PortableRemoteObject.narrow(
            Misc.<Object>lookup(AccessorUtil.RUNTIMEAPI_JNDINAME, jndiEnvironment), EJB2RuntimeAPIHome.class);
        runtimeAPI = runtimeAPIHome.create();
      } catch (RemoteException e) {
        throw new BonitaInternalException(e.getMessage(), e);
      } catch (CreateException e) {
        throw new BonitaInternalException(e.getMessage(), e);
      } catch (NamingException e) {
        throw new BonitaInternalException(e.getMessage(), e);
      }
    }
    Class<RuntimeAPI> clazz = RuntimeAPI.class;
    ClientAPIInterceptor apiInterceptor = new ClientAPIInterceptor(runtimeAPI);
    return (RuntimeAPI) Proxy.newProxyInstance(APIAccessor.class.getClassLoader(),
        new Class[] {clazz}, apiInterceptor);
  }

}
