package org.ow2.bonita.facade.exception;

import org.ow2.bonita.facade.uuid.ProcessDefinitionUUID;
import org.ow2.bonita.util.BonitaException;
/**
 * Thrown by the ManagementAPI if a failure during the deployment operation occured.
 * @author Marc Blachon, Guillaume Porcher, Charles Souillard, Miguel Valdes, Pierre Vigneras
 */
public class DeploymentException extends BonitaException {

  private static final long serialVersionUID = 6967327173196513880L;
  private final String className;
  private final ProcessDefinitionUUID processUUID;

  /**
   * Constructs an DeploymentException with the specified detail message.
   * ClassName and processDefinitionUUID are set to null.
   * @param msg the detail message.
   */
  public DeploymentException(String msg) {
    super(msg);
    this.className = null;
    this.processUUID = null;
  }

  /**
   * Constructs a DeploymentException with the specified detail message and the throwable cause.
   * ClassName and processDefinitionUUID are set to null.
   * @param msg the detail message.
   * @param cause exception causing the abort.
   */
  public DeploymentException(String msg, Throwable cause) {
    super(msg, cause);
    this.className = null;
    this.processUUID = null;
  }

  /**
   * Constructs a DeploymentException with the specified detail message and className parameter.
   * processId is set to null.
   * @param msg the detail message.
   * @param className the name of the class to deploy.
   */
  public DeploymentException(String msg, String className) {
    super(msg + className);
    this.className = className;
    this.processUUID = null;
  }

  /**
   * Constructs a DeploymentException with the specified detail message and className, processDefinitionUUID parameters.
   * @param msg the detail message.
   * @param className the name of the class to deploy.
   * @param processUUID the UUID of the process.
   */
  public DeploymentException(String msg, String className, ProcessDefinitionUUID processUUID) {
    super(msg + " className: " + className + " processDefinitionUUID: " + processUUID);
    this.className = className;
    this.processUUID = processUUID;
  }

  public String getClassName() {
    return this.className;
  }

  public ProcessDefinitionUUID getProcessDefinitionUUID() {
    return this.processUUID;
  }

}
