package org.ow2.bonita.facade.internal;

import java.rmi.RemoteException;
import java.util.Collection;

import org.ow2.bonita.facade.def.element.BusinessArchive;
import org.ow2.bonita.facade.def.majorElement.ProcessDefinition;
import org.ow2.bonita.facade.exception.DeploymentException;
import org.ow2.bonita.facade.exception.ProcessNotFoundException;
import org.ow2.bonita.facade.exception.UndeletableInstanceException;
import org.ow2.bonita.facade.exception.UndeletableProcessException;
import org.ow2.bonita.facade.uuid.ProcessDefinitionUUID;

/**
 * For internal use only.
 */
public interface InternalManagementAPI {

  ProcessDefinition deploy(final BusinessArchive businessARchive) throws DeploymentException, RemoteException;

  void deployClass(byte[] clazz) throws DeploymentException, RemoteException;

  void deployClasses(Collection<byte[]> classes) throws DeploymentException, RemoteException;

  void deployClassesInJar(byte[] classesArchive) throws DeploymentException, RemoteException;

  void undeploy(final ProcessDefinitionUUID processUUID) throws DeploymentException, RemoteException;

  void removeClass(String className) throws DeploymentException, RemoteException;

  void removeClasses(String[] classNames) throws DeploymentException, RemoteException;

  void replaceClass(String className, byte[] newClazz) throws DeploymentException, RemoteException;

  void deleteProcess(ProcessDefinitionUUID processUUID) throws ProcessNotFoundException,
  UndeletableProcessException, UndeletableInstanceException, RemoteException;
  
  void deleteAllProcesses() throws UndeletableProcessException, UndeletableInstanceException, RemoteException;
  
  String getLoggedUser() throws RemoteException;
  
  void addMetaData(String key, String value) throws RemoteException;
  
  String getMetaData(String key) throws RemoteException;
  
  void deleteMetaData(String key) throws RemoteException;
}
