/**
 * Copyright (C) 2007  Bull S. A. S.
 * Bull, Rue Jean Jaures, B.P.68, 78340, Les Clayes-sous-Bois
 * This library is free software; you can redistribute it and/or modify it under the terms
 * of the GNU Lesser General Public License as published by the Free Software Foundation
 * version 2.1 of the License.
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 * You should have received a copy of the GNU Lesser General Public License along with this
 * program; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
 * Floor, Boston, MA  02110-1301, USA.
 * 
 * Modified by Charles Souillard - BonitaSoft S.A.
 * Modified by Matthieu Chaffotte - BonitaSoft S.A.
 **/
package org.ow2.bonita.facade.internal;

import java.rmi.RemoteException;
import java.util.Collection;
import java.util.List;
import java.util.Map;
import java.util.Set;

import org.ow2.bonita.facade.exception.ActivityNotFoundException;
import org.ow2.bonita.facade.exception.InstanceNotFoundException;
import org.ow2.bonita.facade.exception.ProcessNotFoundException;
import org.ow2.bonita.facade.exception.TaskNotFoundException;
import org.ow2.bonita.facade.exception.VariableNotFoundException;
import org.ow2.bonita.facade.runtime.ActivityInstance;
import org.ow2.bonita.facade.runtime.ActivityState;
import org.ow2.bonita.facade.runtime.Comment;
import org.ow2.bonita.facade.runtime.ProcessInstance;
import org.ow2.bonita.facade.runtime.TaskInstance;
import org.ow2.bonita.facade.uuid.ActivityInstanceUUID;
import org.ow2.bonita.facade.uuid.ProcessDefinitionUUID;
import org.ow2.bonita.facade.uuid.ProcessInstanceUUID;

/**
 * For internal use only.
 */
public interface InternalQueryRuntimeAPI {

  ProcessInstance getProcessInstance(ProcessInstanceUUID instanceUUID, 
      String queryList) throws InstanceNotFoundException, RemoteException;

  Set<ProcessInstance> getProcessInstances(String queryList) throws RemoteException;
  
  Set<ProcessInstance> getProcessInstances(Collection<ProcessInstanceUUID> instanceUUIDs, String queryList) throws RemoteException;
  
  Set<ProcessInstance> getProcessInstancesWithTaskState(Collection<ActivityState> activityStates, String queryList) throws RemoteException;

  Set<ProcessInstance> getProcessInstances(ProcessDefinitionUUID processUUID, 
      String queryList) throws ProcessNotFoundException, RemoteException;

  ActivityInstance getActivityInstance(ActivityInstanceUUID
      activityUUID, String queryList) throws ActivityNotFoundException, RemoteException;

  Set<ActivityInstance> getActivityInstances(
      ProcessInstanceUUID instanceUUID, String queryList) throws InstanceNotFoundException, RemoteException;

  Set<ActivityInstance> getActivityInstances(ProcessInstanceUUID instanceUUID,
      String activityId, String queryList) throws InstanceNotFoundException, ActivityNotFoundException, RemoteException;

  TaskInstance getTask(ActivityInstanceUUID taskUUID, String queryList) throws TaskNotFoundException, RemoteException;

  Set<TaskInstance> getTasks(
      ProcessInstanceUUID instanceUUID, String queryList) throws InstanceNotFoundException, RemoteException;

  Collection<TaskInstance> getTaskList(ProcessInstanceUUID instanceUUID, 
      ActivityState taskState, String queryList) throws InstanceNotFoundException, RemoteException;

  Collection<TaskInstance> getTaskList(ActivityState taskState, String queryList) throws RemoteException;

  Object getActivityInstanceVariable(ActivityInstanceUUID activityUUID,
      String variableId, String queryList) throws ActivityNotFoundException, VariableNotFoundException, RemoteException;

  Map<String, Object> getActivityInstanceVariables(ActivityInstanceUUID
      activityUUID, String queryList)throws ActivityNotFoundException, RemoteException;

  Object getProcessInstanceVariable(ProcessInstanceUUID instanceUUID,
      String variableId, String queryList) throws InstanceNotFoundException, VariableNotFoundException, RemoteException;

  Map<String, Object> getProcessInstanceVariables(ProcessInstanceUUID
      instanceUUID, String queryList) throws InstanceNotFoundException, RemoteException;

  Object getVariable(ActivityInstanceUUID activityUUID,
      String variableId, String queryList) throws ActivityNotFoundException, VariableNotFoundException, RemoteException;
  Map<String, Object> getVariables(ActivityInstanceUUID activityUUID, String queryList)
    throws InstanceNotFoundException, ActivityNotFoundException, RemoteException;
  Collection<TaskInstance> getTaskList(ProcessInstanceUUID instanceUUID, 
      String userId, ActivityState taskState, String queryList)
    throws InstanceNotFoundException, RemoteException;
  Collection<TaskInstance> getTaskList(String userId, 
      ActivityState taskState, String queryList) throws RemoteException;

  List<Comment> getCommentFeed(ProcessInstanceUUID instanceUUID, String queryList) throws InstanceNotFoundException, RemoteException;
}
