/**
 * Copyright (C) 2007  Bull S. A. S.
 * Bull, Rue Jean Jaures, B.P.68, 78340, Les Clayes-sous-Bois
 * This library is free software; you can redistribute it and/or modify it under the terms
 * of the GNU Lesser General Public License as published by the Free Software Foundation
 * version 2.1 of the License.
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 * You should have received a copy of the GNU Lesser General Public License along with this
 * program; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
 * Floor, Boston, MA  02110-1301, USA.
 * 
 * Modified by Matthieu Chaffotte - BonitaSoft S.A.
 **/
package org.ow2.bonita.facade.internal;

import java.rmi.RemoteException;
import java.util.Map;

import org.ow2.bonita.facade.exception.ActivityNotFoundException;
import org.ow2.bonita.facade.exception.IllegalTaskStateException;
import org.ow2.bonita.facade.exception.InstanceNotFoundException;
import org.ow2.bonita.facade.exception.ProcessNotFoundException;
import org.ow2.bonita.facade.exception.TaskNotFoundException;
import org.ow2.bonita.facade.exception.UncancellableInstanceException;
import org.ow2.bonita.facade.exception.UndeletableInstanceException;
import org.ow2.bonita.facade.exception.VariableNotFoundException;
import org.ow2.bonita.facade.uuid.ActivityInstanceUUID;
import org.ow2.bonita.facade.uuid.ProcessDefinitionUUID;
import org.ow2.bonita.facade.uuid.ProcessInstanceUUID;
import org.ow2.bonita.util.GroovyException;

/**
 * For internal use only.
 */
public interface InternalRuntimeAPI {

  ProcessInstanceUUID instantiateProcess(ProcessDefinitionUUID processUUID) throws ProcessNotFoundException, RemoteException;

  ProcessInstanceUUID instantiateProcess(ProcessDefinitionUUID processUUID, Map<String, Object> variables)
    throws ProcessNotFoundException, RemoteException, VariableNotFoundException;

  void startTask(ActivityInstanceUUID taskUUID, boolean assignTask) throws TaskNotFoundException, IllegalTaskStateException, RemoteException;

  void finishTask(ActivityInstanceUUID taskUUID, boolean taskAssign) throws TaskNotFoundException, IllegalTaskStateException, RemoteException;

  void suspendTask(ActivityInstanceUUID taskUUID, boolean assignTask) throws TaskNotFoundException,
    IllegalTaskStateException, RemoteException;

  void resumeTask(ActivityInstanceUUID taskUUID, boolean taskAssign) throws TaskNotFoundException,
    IllegalTaskStateException, RemoteException;

  void setProcessInstanceVariable(ProcessInstanceUUID instanceUUID, String variableId, Object variableValue)
    throws InstanceNotFoundException, RemoteException, VariableNotFoundException;

  void setActivityInstanceVariable(ActivityInstanceUUID activityUUID, String variableId,
      Object variableValue) throws ActivityNotFoundException, VariableNotFoundException, RemoteException;

  void cancelProcessInstance(ProcessInstanceUUID instanceUUID) throws InstanceNotFoundException,
    UncancellableInstanceException, RemoteException;

  void deleteProcessInstance(ProcessInstanceUUID instanceUUID) throws InstanceNotFoundException,
    UndeletableInstanceException, RemoteException;

  void deleteAllProcessInstances(ProcessDefinitionUUID processUUID) throws ProcessNotFoundException,
    UndeletableInstanceException, RemoteException;

  void assignTask(ActivityInstanceUUID taskUUID) throws TaskNotFoundException, RemoteException;
  void assignTask(ActivityInstanceUUID taskUUID, String actorId) throws TaskNotFoundException, RemoteException;
  void assignTask(ActivityInstanceUUID taskUUID, java.util.Set<java.lang.String> candidates) throws TaskNotFoundException, RemoteException;
  void unassignTask(ActivityInstanceUUID taskUUID) throws TaskNotFoundException, RemoteException;

  void setVariable(ActivityInstanceUUID activityUUID, String variableId, Object variableValue)
    throws ActivityNotFoundException, VariableNotFoundException, RemoteException;

  void addComment(final ProcessInstanceUUID instanceUUID, ActivityInstanceUUID activityUUID, String message, String userId)
    throws InstanceNotFoundException, ActivityNotFoundException, RemoteException;

  void addProcessMetaData(ProcessDefinitionUUID uuid, String key, String value) throws ProcessNotFoundException, RemoteException;

  void deleteProcessMetaData(ProcessDefinitionUUID uuid, String key) throws ProcessNotFoundException, RemoteException;
  
  Object evaluateGroovyExpression(String expression, ProcessInstanceUUID instanceUUID)
    throws InstanceNotFoundException, GroovyException, RemoteException;
  
  Object evaluateGroovyExpression(String expression, ActivityInstanceUUID activityUUID)
    throws InstanceNotFoundException, ActivityNotFoundException, GroovyException, RemoteException;
}
